Learn R Programming

gtakeout (version 0.1.0)

gtakeout_reviews: Extract the reviews form a Takedown zip file. #'

Description

Extract the reviews form a Takedown zip file. #'

Usage

gtakeout_reviews(zipfile, ..., exdir = here::here("data"))

Value

A data frame of reviews

Arguments

zipfile

Required path to the zip file containing the reviews

...

Other optional arguments

exdir

Optional directory to extract the contents of the zip file

Examples

Run this code
zip_path <- system.file(
    "extdata",
    "takeout-example.zip",
    package = "gtakeout"
)
gtakeout_reviews(zip_path, exdir = tempdir())

Run the code above in your browser using DataLab