powered by
Extract the reviews form a Takedown zip file. #'
gtakeout_reviews(zipfile, ..., exdir = here::here("data"))
A data frame of reviews
Required path to the zip file containing the reviews
Other optional arguments
Optional directory to extract the contents of the zip file
zip_path <- system.file( "extdata", "takeout-example.zip", package = "gtakeout" ) gtakeout_reviews(zip_path, exdir = tempdir())
Run the code above in your browser using DataLab